# spec file for package ibus-typing-booster
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           ibus-typing-booster
Version:        1.5.36
Release:        lp150.1.2
Summary:        An input completion utility
License:        GPL-3.0+
Group:          System/X11/Utilities
URL:            https://mike-fabian.github.io/ibus-typing-booster/
Source0:        https://github.com/mike-fabian/ibus-typing-booster/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://releases.pagure.org/inscript2/inscript2-20160423.tar.gz
BuildRequires:  ibus-devel
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  desktop-file-utils
BuildRequires:  python3-gobject
BuildRequires:  dbus-1-x11
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
# for the unit tests
BuildRequires:  m17n-lib
BuildRequires:  m17n-db
BuildRequires:  python3-pyenchant
%if 0%{?sle_version} >= 120200
BuildRequires:  python3-pyxdg
%endif
%if 0%{?suse_version} == 1320
BuildRequires:  myspell-cs_CZ
BuildRequires:  myspell-de
BuildRequires:  myspell-en
BuildRequires:  myspell-es
BuildRequires:  myspell-it_IT
%else
BuildRequires:  myspell-cs_CZ
BuildRequires:  myspell-de
BuildRequires:  myspell-de_DE
BuildRequires:  myspell-en
BuildRequires:  myspell-en_US
BuildRequires:  myspell-es
BuildRequires:  myspell-es_ES
BuildRequires:  myspell-fr_FR
BuildRequires:  myspell-it_IT
%endif
#
Requires:       ibus >= 1.5.3
Requires:       m17n-lib
Requires:       python3 >= 3.3
Requires:       dbus-1-python3
Requires:       python3-pyenchant
Requires:       python3-pyxdg
# Recommend reasonably good fonts which have most of the emoji:
Recommends:     noto-coloremoji-fonts
Recommends:     gdouros-symbola-fonts
#

%description
Ibus-typing-booster is a context sensitive completion
input method to speedup typing.

%prep
%setup -q
##extract inscript2 maps
tar xzf %{SOURCE1}

%build
export PYTHON=%{_bindir}/python3
%configure --disable-static --disable-additional --libexecdir=%{_libdir}/ibus
make %{?_smp_mflags}

%install
export PYTHON=%{_bindir}/python3
make install DESTDIR=%{buildroot} NO_INDEX=true
gzip -n --force --best %{buildroot}/%{_datadir}/%{name}/data/*.{txt,json} \
    %{buildroot}/%{_datadir}/%{name}/data/annotations/*.xml \
    %{buildroot}/%{_datadir}/%{name}/data/annotationsDerived/*.xml

#install inscript2 keymaps
test -d %{buildroot}%{_datadir}/m17n/icons || mkdir -p %{buildroot}%{_datadir}/m17n/icons
cp -p inscript2/IM/* %{buildroot}%{_datadir}/m17n/
cp -p inscript2/icons/* %{buildroot}%{_datadir}/m17n/icons

%suse_update_desktop_file -i -u emoji-picker GTK Utility

%fdupes %{buildroot}/%{_prefix}

%find_lang %{name}

%check
export LC_ALL=en_US.UTF-8
export M17NDIR=%{buildroot}%{_datadir}/m17n/
desktop-file-validate \
    %{buildroot}%{_datadir}/applications/ibus-setup-typing-booster.desktop
pushd engine
    # run doctests
    python3 hunspell_suggest.py
    python3 m17n_translit.py
    python3 itb_emoji.py
    python3 itb_util.py
popd
eval $(dbus-launch --sh-syntax)
dconf dump /
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/offtherecord false
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/usedigitsasselectkeys true
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/tabenable false
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/inputmethod "'NoIme'"
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/adddirectinput false
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/rememberlastusedpreeditime true
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/mincharcomplete 1
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/dictionary "'en_US'"
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/emojipredictions true
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/autocommitcharacters "''"
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/pagesize 6
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/shownumberofcandidates true
dconf write /desktop/ibus/engine/typing-booster/typing-booster-de-de/showstatusinfoinaux true
dconf dump /
ibus-daemon -drx
make check || cat ./tests/test-suite.log

%post
[ -x %{_bindir}/ibus ] && \
  %{_bindir}/ibus write-cache --system &>/dev/null || :

%postun
[ -x %{_bindir}/ibus ] && \
  %{_bindir}/ibus write-cache --system &>/dev/null || :

%files -f %{name}.lang
%doc AUTHORS COPYING README
%{_bindir}/emoji-picker
%{_datadir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*.appdata.xml
%{_datadir}/ibus/component/typing-booster.xml
%{_libdir}/ibus/ibus-engine-typing-booster
%{_libdir}/ibus/ibus-setup-typing-booster
%{_datadir}/applications/*.desktop
%dir %{_datadir}/m17n
%{_datadir}/m17n/*.mim
%dir %{_datadir}/m17n/icons
%{_datadir}/m17n/icons/*.png

%changelog
* Tue Apr 10 2018 maiku.fabian@gmail.com
- update to 1.5.35
- Make the default for self.show_status_info_in_auxiliary_text False
  (Resolves: rhbz#156435)
- Adapt hunspell_suggest.py to work with pyhunspell 0.5.4
* Tue Mar 13 2018 maiku.fabian@gmail.com
- update to 1.5.35
- Update translations from zanata (es, pl and uk updated)
- Update UnicodeData.txt to UnicodeData-11.0.0d13.txt
- Read also the emoji names from the emoji-test.txt file
- Update Unicode emoji data to a prerelease of Unicode Emoji Data 11.0
- Fix PyGTKDeprecationWarning: Using positional arguments with the
  GObject constructor has been deprecated.
- Add “Twemoji” as a good colour emoji font to the emoji-picker font list
- Don’t show the languages en_001 and  es_419 in the browsing treeview
- Use romaji=True by default in EmojiMatcher
- Update emoji annotations from CLDR
* Fri Jan  5 2018 bwiedemann@suse.com
- Use gzip -n to not include build timestamps in .gz headers
* Wed Nov 29 2017 badshah400@gmail.com
- Specfile cleanup:
  * Update source URLs; fedorahosted has been retired.
  * Fix package Group.
  * Run spec-cleaner for minor formatting clean-ups.
* Thu Oct  5 2017 maiku.fabian@gmail.com
- update to 1.5.34
- Update translations from zanata (cs new, de updated)
- Add some tooltips
- Add an option whether to use pango font fallback to emoji-picker
- Update emoji annotations from CLDR
- Add Recommends: google-noto-emoji-color-fonts
* Mon Sep 11 2017 maiku.fabian@gmail.com
- update to 1.5.33
- Update translations from zanata (es new)
- Install appstream metadata to /usr/share/metainfo/
- Update UnicodeData.txt to Unicode 10.0.0
- Fix test cases and kakasi support for the update of the
  emoji annotations from CLDR
- Update emoji annotations from CLDR
- Skip the emoji which already have skin tone modifiers
  in itb_emoji.emoji_by_label()
- Never load characters of Unicode categories “Cc”, “Co”,
  and “Cs” into the emoji dictionary
- Update emoji-data.txt to 5.0
* Mon Apr 24 2017 maiku.fabian@gmail.com
- update to 1.5.32
- Fix error when starting emoji-picker when the “recently-used” does not yet exist
- Update emojione.json to version 3.0
- Add the data from CLDR common/annotationsDerived
- Load also the CLDR annotations from “annotationsDerived”
* Tue Apr 18 2017 maiku.fabian@gmail.com
- update to 1.5.31
- Rename option --use_vs16 to --non_fully_qualified
  (effectivly reversing the default)
- Make description labels in info popover selectable to be able
  to copy and paste their contents
- Sort similar emoji with the same number of matching labels
  by cldr_order distance
- Map cldr subgroup 'person-sport' to emojione category 'activity'
- Make the categorie listings and the search work right
  when using --use_vs16
- Always store only non-fully-qualified emoji or emoji-sequences
  in the internal dictionary
- Update emoji annotations from CLDR
* Mon Apr  3 2017 maiku.fabian@gmail.com
- update to 1.5.30
- Update translations from zanata (de, pl, uk updated)
- Use string order as a fallback to cldr_order in category listings
- The rainbow flag should be a zwj sequence
- Also display the Unicode version in the emoji info popover
- When looking up emoji or other characters via Unicode codepoint,
  ignore surrogates and private use characters
- Show the fonts really used to render an emoji in the
  info popover for the emoji
- Fix typo in translatable string
- itb_emoji.py: Use CLDR order to sort the candidates and
  the similar emoji if score is the same
* Tue Mar 21 2017 maiku.fabian@gmail.com
- update to 1.5.29
- Add Recommends: noto-coloremoji-fonts, “Noto Color Emoji”
  looks much better than “Symbola” even in gray scale.
- Update translations from zanata (de, pl updated)
- Add a “--version” command line option to emoji-picker
- itb_emoji.py: Also read emoji-test.txt (from unicode.org)
- emoji-picker: Set default font to first available in
  ['Noto Color Emoji', 'Emoji One', 'Symbola']
- Small parsing improvement of emoji-sequences.txt
- Add support to either use U+FE0F VARIATION SELECTOR-16 in emoji sequences or not
- emoji-picker: Show “∅ Search produced empty result.” when nothing matches in a search
* Sat Mar 18 2017 maiku.fabian@gmail.com
- update to 1.5.28
- Allow query by code point even if Python’s unicodedata.name()
  does not know the character
- Also read names from emoji-sequences.txt and emoji-zwj-sequences.txt
- itb_emoji.py: Also read emoji-sequences.txt (from unicode.org)
- Fix positioning of info popover (fix a typo in an “if” statement)
- Show emoji properties from unicode.org when debugging is on
- itb_emoji.py: Also read emoji-zwj-sequences.txt (from unicode.org)
- Also use the emoji properties from unicode.org to decide whether
  to offer a lookup on emojipedia
- Use property “Emoji_Modifier_Base” from emoji-data.txt to check
  whether an emoji supports skin tones
- itb_emoji.py: Also read emoji-data.txt (from unicode.org)
- Tentative skin tone support for families
- Improve skin tone support: make it work for professions (roles) as well
- Make skin tone popover scrollable and limit its maximum size
* Fri Mar 17 2017 maiku.fabian@gmail.com
- update to 1.5.27
- Update translations from zanata (pl, uk updated)
- emoji-picker: make skin tone selection work for gendered emoji
* Thu Mar 16 2017 maiku.fabian@gmail.com
- update to 1.5.26
- Update translations from zanata (de updated)
- Emulate xdg.BaseDirectory.save_data_path() on systems which lack pyxdg
- Show the skin tone popover also on a long press gesture
- Fix pyhunspell support
  Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/5#issuecomment-286251818
* Tue Mar 14 2017 maiku.fabian@gmail.com
- add python3-pyxdg to BuildRequires only for
  0%%{?sle_version} >= 120200
* Mon Mar 13 2017 maiku.fabian@gmail.com
- add python3-pyxdg to BuildRequires
* Mon Mar 13 2017 maiku.fabian@gmail.com
- update to 1.5.25
- Update translations from zanata (de, pl, uk updated, zh_CN new)
- Show the categories as well on right mouse click in emoji-picker
- Improve information displayed on right mouse click in emoji-picker
- html.unescape() the strings parsed from the cldr annotations
- Fix fontsize change for invisible emoji in browse flowbox
- Add an option whether the arrow keys are allowed to reopen a preëdit
- Add an option to work around the broken forward_key_event()
  in the Qt 4/5 im module
- Use xdg.BaseDirectory to add a USER_DATADIR to the
  search path for data for itb_emoji.py
- emoji_picker.py: Speedup: Fix wrong indentation of block
  in _fill_flowbox_browse()
- emoji_picker.py: Print some profiling information when debugging is enabled
- Store the clipboard with gtk_clipboard_store() to keep it around
  after emoji-picker quits
- emoji-picker: Do not override the decoration layout of the header bar
- When an emoji with a different skin tone is selected,
  replace the original emoji immediately
- Make emoji-picker work on dark themes like Adwaita-dark as well
* Mon Mar  6 2017 maiku.fabian@gmail.com
- update to 1.5.24
- Update translations from zanata (de updated)
- The spin button to change the fontsize should grab focus without selecting
- emoji-picker: Don’t check if ibus is running,
  ibus does not need to run for emoji-picker
- Load .desktop files for emoji-picker and ibus-setup-typing-booster
  correctly under Gnome Wayland
- Show the most recently used skin tone by default
- Use Popovers for skin tones
- Don’t use HeaderBar with the default widget titlebar
- Display the detailed information of an emoji as a popover, not as a tooltip
- Use CSS to show light gray borders around flowbox and listbox children
* Mon Feb 27 2017 maiku.fabian@gmail.com
- remove fix-emoji-picker-desktop-file.patch (fixed upstream)
* Mon Feb 27 2017 maiku.fabian@gmail.com
- update to 1.5.23
- Update translations from zanata (de, ja, pl, uk updated)
- emoji_picker.py: Add a menu button to change the font for the emoji
- emoji-picker: Make background colour of the flowbox listing the emoji white
- emoji-picker: Use “Symbola” as the default font
- Remember the font and the fontsize in a config file
- emoji_picker.py: Add a spin button to change the font size of the emoji
- Add option to the emoji-picker to load *all* Unicode characters
- UI redesign of the emoji-picker
- Return an empty list immediately if candidates() is called with an empty search string
- Make the fontsize for the names of the emoji in the search results smaller
- Make the search in emoji-picker a bit more responsive by using GLib.idle_add()
- Save the recently used emoji immediately, not only when the program quits
- Set default font size of emoji-picker to 24 instead of 16
- Set the emoji font only for the emoji, not for its name in the search results
- Set WM_CLASS of emoji-picker and ibus-setup-typing-booster correctly
- Add “Icon” and “Categories” to emoji-picker.desktop
* Fri Feb 24 2017 maiku.fabian@gmail.com
- Remove "Buildarch: noarch" again
  (does not build when --libexecdir=%%{_prefix}/%%{_lib}/ibus is used
  but that probably has to be used)
* Wed Feb 22 2017 maiku.fabian@gmail.com
- make it noarch
* Wed Feb 22 2017 maiku.fabian@gmail.com
- fix build (thanks to Stefan Dirsch)
* Wed Feb 22 2017 maiku.fabian@gmail.com
- fix emoji-picker desktop file
* Wed Feb 22 2017 maiku.fabian@gmail.com
- update to 1.5.22
- Update translations from zanata (de, fr, pl, uk updated)
- Add an emoji-picker
- Update of en.xml from CLDR’s emoji annotations
- Fix skipping of the Korean test case when no Korean dictionary can be found
- Fix invalid xml in typing-booster.appdata.xml
- add Requires: python3-pyxdg (for the emoji-picker)
* Wed Feb  8 2017 maiku.fabian@gmail.com
- add BuildRequires:  python3
  This seems to contain sqlite3, needed for "make check"
* Tue Feb  7 2017 maiku.fabian@gmail.com
- update to 1.5.21
- add BuildRequires:  hunspell-fr_FR (for make check)
- Handle Return and Enter correctly when the cursor is not at
  the end of the preëdit (Resolves: rhbz#1418313)
- Values of spin buttons should not be translatable
- Make the categories from emojione translatable
- Make emoji matching accent insensitive
- If available use pykakasi to convert Japanese emoji category
  names to hiragana
- If available use the “pinyin” Python module to add pinyin
  to the Chinese names and keywords
- Don’t fallback to “zh” from “zh_TW”, “zh_HK”, “zh_MO” and “zh_Hant”
- Don’t sort the labels when listing similar emoji
- Don’t change Unicode categories to lowercase when loading,
  use the original case
- Also treat categories 'Zl' and 'Zp' as invisible and add
  Unicode code point
- When searching for similar emoji, the original emoji should be
  most similar to itself
- Fix duplicate listing of labels when looking up similar emoji
- Make it optionally possible to match emoji in Japanese using romaji
- itb_emoji.py: Add the code point to the name of invisible
  characters also when looking up similar characters
- Better matching of the Unicode categories
- Small performance optimization in EmojiMatcher.similar()
- Remove any U+2028 LINE SEPARATOR and U+2029 PARAGRAPH SEPARATOR characters
  from the lookup table
- Nicer display of the matching labels when looking up similar emoji
- Don’t strip mathematical symbols (category 'Sm') from tokens
- Update of en.xml from CLDR’s emoji annotations
- Update translations from zanata (de, pl updated)
* Fri Jan 27 2017 maiku.fabian@gmail.com
- update to 1.5.20
- Calculate the maximum word length for each dictionary individually
- Use .startswith instead of regexp matching when matching in hunspell
  dictionaries (speed optimization)
- Improve accent insensitive matching (“filosofičtějš” should also
  match “filosofičtější”)
- Some updates for the emoji annotations in en.xml from CLDR
* Thu Jan 19 2017 maiku.fabian@gmail.com
- update to 1.5.19
- Improve setup layout (thanks to Trinh Anh Ngoc <atw1990@gmail.com>)
- Add some more directories to search for dictionaries (for FreeBSD)
- Wrong variable “page_size” was used in set_lookup_table_orientation()
- Do not try to reopen the preëdit when any modifier except
  CapsLock is on (Resolves: rhbz#1414642)
* Tue Jan 17 2017 maiku.fabian@gmail.com
- update to 1.5.18
- Fix typo in the “Unbreak sqlite on Python 3.6” patch
- Fix the fallback to use pyhunspell-python3 when python3-enchant
  is not available
- Remove useless ibus-typing-booster.pc
* Fri Jan 13 2017 maiku.fabian@gmail.com
- update to 1.5.17
- Update py-compile to current upstream version
- Also use ＿ U+FF3F FULLWIDTH LOW LINE as a separator for emoji keywords
- Unbreak sqlite on Python 3.6 (thanks to Jan Alexander Steffens)
- Return immediately if _update_candidates() is called with
  empty input (Resolves: rhbz#1413082)
* Tue Jan 10 2017 maiku.fabian@gmail.com
- update  to 1.5.16
- Remove everything following a tab (including the tab) from
  hunspell dictionary lines (Resolves: rhbz#1411659)
- Delete a candidate correctly from the user database even if
  it starts with a prefix to be stripped from tokens (Resolves: rhbz#1411676)
- Trigger emoji lookup when the input starts or ends with '_' or ' '
- Better handling of BackSpace and Delete when reaching the
  ends of the preëdit (Resolves: rhbz#1411688)
- Search for hunspell dictionaries in a list of directories
  (Resolves: https://github.com/mike-fabian/ibus-typing-booster/issues/6)
* Thu Dec  8 2016 maiku.fabian@gmail.com
- first version for SuSE 1.5.15
